# mondossierweb

Get grades and detect changes in your grades, on schools using mon dossier web (mdw.(school domain))

## Installation

```bash
pip install mondossierweb
```

## Usage

```
Usage: mondossierweb [USERNAME] [PASSWORD_COMMAND] [GRADE_CODE] [SAVE_AS]
       mondossierweb --help
```
